/*
 * PWM Demo
 * Arduino
 *
 * This code uses pulse width modulation (PWM) to control the brightness of the
 * LED. The LED slowly gets brighter and then dimmer in a loop.
 *
 * The following external hardware is required:
 *   - a wire connecting pin 11 to pin 13
 *
 * @author Gabe Cohn
 * @date 02/01/2012 - Gabe Cohn     @li initial revision
 ******************************************************************************/

/* constants */
#define BRIGHT_CHG_PERIOD   10  // milliseconds between LED brightness chagnes

/* pin definitions */
#define LED     13              // LED is on pin 13
#define LED_PWM 11              // PWM output which we will use for the LED

/* variables */
byte ledBrightness = 1;         // LED brightness (PWM value)
char delta = 1;                 // amount to change brightness each step

/* initialization code */
void setup() {                
    pinMode(LED, INPUT);        /* set LED pin as an input so that it does 
                                 * not interfere with the PWM signal which
                                 * is also connected (externally) to the
                                 * same pin */
    digitalWrite(LED, LOW);     // disable pull-up resistor
}

/* mainloop - runs forever */
void loop() {

    // change brightness directions at end of scale
    if (ledBrightness == 0 || ledBrightness == 255) {
        delta *= -1;           //flip brightness change direction
    }
    
    ledBrightness += delta;    // change brightness setting
    analogWrite(LED_PWM, ledBrightness); // set new brightness
    
    // wait before changing brightness again
    delay(BRIGHT_CHG_PERIOD);
}
